@@ -72,25 +72,22 @@ class PortalNamespace:
 
     async def login_client(
         self,
-        client_id: str,
         psk: str,
         tenant_id: Optional[str] = None
     ) -> Dict[str, Any]:
         """
         Login service client with PSK.
 
+        Client is looked up by PSK directly - no client_id needed.
+
         Args:
-            client_id: Client UUID
             psk: Pre-shared key
             tenant_id: Optional tenant UUID. If not provided, uses client's first assigned tenant.
 
         Returns:
             Dict with access_token, token_type, expires_in, session_id
         """
-        body: Dict[str, str] = {
-            "client_id": client_id,
-            "psk": psk
-        }
+        body: Dict[str, str] = {"psk": psk}
         if tenant_id:
             body["tenant_id"] = tenant_id
         return await self._client._request(
